/* eslint-disable react/jsx-props-no-spreading */
import React from 'react';
import moment from 'moment';
import { Icon, Button } from 'mkui-fd';
import { Currency } from 'mkui-ext';
import { InvoiceModalPropTypes, InvoiceModalDefaultProps } from './PropTypes';
import { pickInvoiceDetail, getValidateStatis } from './utils';
import { DETAIL_MAPPER } from './constant';

var Text = function Text(_ref) {
  var content = _ref.content,
      item = _ref.item,
      symbol = _ref.symbol;

  switch (item) {
    case 'issueDate':
      return moment(content[item]).format('YYYY-MM-DD');

    case 'totalTaxAmount':
    case 'totalPriceAmount':
    case 'totalPriceAndTax':
      return /*#__PURE__*/React.createElement(Currency, {
        value: content[item],
        symbol: symbol,
        size: "small"
      });

    default:
      return content[item];
  }
};

var renderInner = function renderInner(content, symbol) {
  return Object.keys(content).map(function (item) {
    return /*#__PURE__*/React.createElement("p", {
      key: item
    }, /*#__PURE__*/React.createElement("span", null, DETAIL_MAPPER[item], ":"), /*#__PURE__*/React.createElement("span", {
      className: "invoice-info"
    }, /*#__PURE__*/React.createElement(Text, {
      content: content,
      item: item,
      symbol: symbol
    })));
  });
};

var renderBtn = function renderBtn(img, onAdjust, prefixCls) {
  if (getValidateStatis(img)) {
    return /*#__PURE__*/React.createElement(Icon, {
      type: "bs-seal-passed-zh",
      className: "".concat(prefixCls, "-modal-passed-icon")
    });
  } else {
    return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Button, {
      type: "primary",
      style: {
        "float": 'right',
        marginTop: 6
      },
      onClick: onAdjust
    }, "\u8C03\u6574"));
  }
};

var InvoiceModal = function InvoiceModal(props) {
  var prefixCls = props.prefixCls,
      img = props.img,
      modalVisible = props.modalVisible,
      onClose = props.onClose,
      onAdjust = props.onAdjust,
      symbol = props.symbol;

  var _pickInvoiceDetail = pickInvoiceDetail(img),
      InvoiceContent = _pickInvoiceDetail.InvoiceContent,
      buyerContent = _pickInvoiceDetail.buyerContent;

  var invoiceTypeDesc = img.invoiceTypeDesc;

  if (modalVisible) {
    return /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-modal")
    }, /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-modal-head")
    }, /*#__PURE__*/React.createElement("span", null, invoiceTypeDesc), /*#__PURE__*/React.createElement(Icon, {
      onClick: onClose,
      className: "modal-icon",
      type: "close"
    })), /*#__PURE__*/React.createElement("div", null, renderInner(InvoiceContent, symbol)), /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-modal-title")
    }, "\u8D2D\u4E70\u65B9"), /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-modal-buyer")
    }, renderInner(buyerContent)), renderBtn(img, onAdjust, prefixCls));
  }

  return null;
};

InvoiceModal.propTypes = InvoiceModalPropTypes;
InvoiceModal.defaultProps = InvoiceModalDefaultProps;
export default InvoiceModal;
//# sourceMappingURL=InvoiceModal.js.map
