import _ from 'lodash';
import { PAGE_SIZE } from './constant';
/**
 * @description: 注册事件
 * @param {type}
 * @return:
 */

export var registerEvent = function registerEvent(obj, sType, fn) {
  if (obj.addEventListener) {
    obj.addEventListener(sType, fn, false);
  } else {
    obj.attachEvent("on".concat(sType), fn);
  }
};
/**
 * @description: 卸载事件
 * @param {type}
 * @return:
 */

export var unmountEvent = function unmountEvent(obj, sType, fn) {
  if (obj.removeEventListener) {
    obj.removeEventListener(sType, fn, false);
  } else {
    obj.detachEvent("on".concat(sType), fn);
  }
};
/**
 * @description: 取消默认事件
 * @param {type}
 * @return:
 */

export var preventDefaultEvent = function preventDefaultEvent(ev) {
  var zoEvent = ev || window.event;

  if (zoEvent.preventDefault) {
    zoEvent.preventDefault();
  }

  return zoEvent;
};
/**
 * @description: 下载图片
 * @param {type}
 * @return:
 */

export var downloadFromLink = function downloadFromLink(href, name) {
  var downloadLink = document.createElement('a');
  downloadLink.href = href;
  downloadLink.download = name || href.split('/')[href.split('/').length - 1];
  document.body.appendChild(downloadLink);
  downloadLink.click();
  document.body.removeChild(downloadLink);
};
/**
 * @description: 获取鼠标移动后图片偏移量
 * @param {type} background 图片父div ref，图片ref，鼠标 move event
 * @from : https://github.com/Caldis/react-zmage
 * @return: left, top
 */

export var getTranslate = function getTranslate(bg, img, e) {
  var mouseX = e.clientX,
      mouseY = e.clientY;

  var _bg$getBoundingClient = bg.getBoundingClientRect(),
      bgLeft = _bg$getBoundingClient.left,
      bgTOP = _bg$getBoundingClient.top;

  var _img$getBoundingClien = img.getBoundingClientRect(),
      naturalWidth = _img$getBoundingClien.width,
      naturalHeight = _img$getBoundingClien.height; // 随鼠标位移偏移量


  var saveEdge = 170;
  var viewWidth = bg.offsetWidth;
  var viewHeight = bg.offsetHeight;
  var rangeX = naturalWidth - viewWidth + 2 * saveEdge;
  var rangeY = naturalHeight - viewHeight + 2 * saveEdge;
  var imgPosX = naturalWidth > viewWidth ? (naturalWidth - viewWidth) / 2 + saveEdge - rangeX * ((mouseX - bgLeft) / viewWidth) : 0;
  var imgPosY = naturalHeight > viewHeight ? (naturalHeight - viewHeight) / 2 + saveEdge - rangeY * ((mouseY - bgTOP) / viewHeight) : 0;
  return {
    imgPosX: imgPosX,
    imgPosY: imgPosY
  };
};
/**
 * @description: 获取导航图片
 * @param: 原图片集、导航图片集起始index
 * @return: 导航图片集
 */

export var getNavImgs = function getNavImgs(imgs, startIndex) {
  return imgs.slice(startIndex, startIndex + PAGE_SIZE);
};
/**
 * @description: 获取发票展示信息对象
 * @param {type} 发票对象
 * @return: detail
 */

export var pickInvoiceDetail = function pickInvoiceDetail(imgs) {
  var InvoiceContent = _.pick(imgs, 'invoiceCode', 'invoiceNumber', 'issueDate', 'checksum', 'totalPriceAmount', 'totalPriceAndTax', 'totalTaxAmount', 'buyerName', 'buyerTaxNumber');

  var buyerContent = _.pick(imgs, 'buyerName', 'buyerTaxNumber');

  return {
    InvoiceContent: InvoiceContent,
    buyerContent: buyerContent
  };
};
export var getValidateStatis = function getValidateStatis(img) {
  return img && img.validateStatus === 'VALIDATED';
};
//# sourceMappingURL=utils.js.map
